.. TRSFX documentation master file, created by
   sphinx-quickstart on Fri Jan 16 14:25:01 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

TRSFX documentation
=======================

Add your content using ``reStructuredText`` syntax. See the
`reStructuredText <https://www.sphinx-doc.org/en/master/usage/restructuredtext/index.html>`_
documentation for details.


.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Python API:

   TRSFX/compare
   TRSFX/explore
   TRSFX/manipulation
   TRSFX/index

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Vignettes:

   vignettes/included
   vignettes/compare
   vignettes/explore
   vignettes/manip
   vignettes/index

.. include:: ../README.md
   :parser: myst_parser.sphinx_


